@@ -454,81 +454,70 @@ local.corr<-function(x,dp.locat, sp.locat,SD)
 
 
 # Randomisation Tests for GWSS
-#montecarlo.gwss<-function(data, summary.locat, vars, kernel = "gaussian", adaptive = FALSE, bw, p = 2, theta = 0, longlat = F, dMat, quantile=FALSE,nsim=99) 
-#{
-#	if (is(data, "Spatial")) {
-#        p4s <- proj4string(data)
-#        dp.locat <- coordinates(data)
-#    }
-#    else if (is(data, "data.frame") && (!missing(dMat))) 
-#        data <- data
-#    else stop("Given data must be a Spatial*DataFrame or data.frame object")
-#    if (missing(summary.locat)) {
-#        sp.given <- FALSE
-#        summary.locat <- data
-#        sp.locat <- coordinates(summary.locat)
-#    }
-#    else {
-#        sp.given <- T
-#        if (is(summary.locat, "Spatial")) 
-#            sp.locat <- coordinates(summary.locat)
-#        else {
-#            warning("Output loactions are not packed in a Spatial object,and it has to be a two-column numeric vector")
-#            summary.locat <- sp.locat
-#        }
-#    }
-#    data <- as(data, "data.frame")
-#    dp.n <- nrow(data)
-#    sp.n <- nrow(sp.locat)
-#    if (missing(dMat)) 
-#        DM.given <- F
-#    else {
-#        DM.given <- T
-#        dim.dMat <- dim(dMat)
-#        if (dim.dMat[1] != dp.n || dim.dMat[2] != sp.n) 
-#            stop("Dimensions of dMat are not correct")
-#    }
-#    if (missing(vars)) 
-#        stop("Variables input error")
-#    if (missing(bw) || bw <= 0) 
-#        stop("Bandwidth is not specified incorrectly")
-#    col.nm <- colnames(data)
-#    var.idx <- match(vars, col.nm)[!is.na(match(vars, col.nm))]
-#    if (length(var.idx) == 0) 
-#        stop("Variables input doesn't match with data")
-#    x <- data[, var.idx]
-#    x <- as.matrix(x)
-#    var.nms <- colnames(x)
-#    var.n <- ncol(x)
-#
-############## 
-#	dataI<-SpatialPointsDataFrame(sp.locat,data.frame(x))
-#
-#	resi<-as.data.frame(gwss(data=dataI, vars=vars, kernel=kernel, adaptive=adaptive, bw=bw, p=p, theta=theta, longlat=longlat, dMat=dMat, quantile=quantile)$SDF)
-#	
-#	nstats<-ncol(resi)-2
-#	
-#	lss.i<-array(0,dim=c(sp.n,nstats,nsim+1))
-#
-#	lss.i[,,1]<- as.matrix(resi[,-c(nstats+1,nstats+2)])
-#	
-#	for(i in 1:nsim)
-#	{
-#		xx<-data[sample(dp.n), var.idx] #x[sample(dp.n),]
-#		
-#		dataI<-SpatialPointsDataFrame(sp.locat,data.frame(xx))
-#		
-#		resi<-as.data.frame(gwss(data=dataI, vars=vars, kernel=kernel, adaptive=adaptive, bw=bw, p=p, theta=theta, longlat=longlat, dMat=dMat, quantile=quantile)$SDF)
-#		
-#		lss.i[,,i+1]<-as.matrix(resi[,-c(nstats+1,nstats+2)])
-#	}
-#	
-#	dimnames(lss.i)[[1]]<-seq(0,sp.n-1)
-#	dimnames(lss.i)[[2]]<-names(resi)[-c(nstats+1,nstats+2)]
-#	dimnames(lss.i)[[3]]<-c('Original_Data',paste('Sample',seq(1:nsim),sep='_'))
-#	
-#	test<-apply(lss.i,c(1,2),function(x,n) rank(x,ties.method='first')[1]/n,n=nsim+1)
-#	
-#	test
-#}
+montecarlo.gwss<-function(data, vars, kernel = "gaussian", 
+                 adaptive = FALSE, bw, p = 2, theta = 0, longlat = F, 
+                 dMat, quantile=FALSE,nsim=99) 
+{
+	if (is(data, "Spatial")) {
+        p4s <- proj4string(data)
+        dp.locat <- coordinates(data)
+    }
+    else if (is(data, "data.frame") && (!missing(dMat))) 
+        data <- data
+    else stop("Given data must be a Spatial*DataFrame or data.frame object")
+    data <- as(data, "data.frame")
+    dp.n <- nrow(data)
+    if (missing(dMat))
+    { 
+        DM.given <- F
+        dMat <- gw.dist(dp.locat=dp.locat, p=p, theta=theta, longlat=longlat)
+    }
+    else {
+        DM.given <- T
+        dim.dMat <- dim(dMat)
+        if (dim.dMat[1] != dp.n || dim.dMat[2] != dp.n) 
+            stop("Dimensions of dMat are not correct")
+    }
+    if (missing(vars)) 
+        stop("Variables input error")
+    if (missing(bw) || bw <= 0) 
+        stop("Bandwidth is not specified incorrectly")
+    col.nm <- colnames(data)
+    var.idx <- match(vars, col.nm)[!is.na(match(vars, col.nm))]
+    if (length(var.idx) == 0) 
+        stop("Variables input doesn't match with data")
+    x <- data[, var.idx]
+    x <- as.matrix(x)
+    var.nms <- colnames(x)
+    var.n <- ncol(x)
+
+ 
+	dataI<-SpatialPointsDataFrame(dp.locat,data.frame(x))
+
+	resi<-(gwss(data=dataI, vars=vars, kernel=kernel, adaptive=adaptive, bw=bw, p=p, theta=theta, 
+                      longlat=longlat, dMat=dMat, quantile=quantile)$SDF)@data
+	
+	nstats<-ncol(resi)
+	
+	lss.i<-array(0,dim=c(dp.n,nstats,nsim+1))
+
+	lss.i[,,1]<- as.matrix(resi)
+	dMat1<- dMat
+	for(i in 1:nsim)
+	{
+		mcs <- sample(dp.n)   	
+		dataI<-SpatialPointsDataFrame(dp.locat[mcs,],data.frame(x))
+		dMat1[mcs,]<-dMat[1:dp.n,]
+		dMat1[,mcs]<-dMat[,1:dp.n]
+		resi<-(gwss(data=dataI, vars=vars, kernel=kernel, adaptive=adaptive, 
+                       bw=bw, p=p, theta=theta, longlat=longlat, dMat=dMat1, quantile=quantile)$SDF)@data		
+		lss.i[,,i+1]<-as.matrix(resi)
+	}
+	
+	dimnames(lss.i)[[1]]<-seq(0,dp.n-1)
+	dimnames(lss.i)[[2]]<-names(resi)
+	dimnames(lss.i)[[3]]<-c('Original_Data',paste('Sample',seq(1:nsim),sep='_'))	
+	test<-apply(lss.i,c(1,2),function(x,n) 1 - rank(x,ties.method='first')[1]/n,n=nsim+1)	
+	test
+}
                                     
\ No newline at end of file
